@@ -30,6 +30,7 @@ class CachetClient(object):
 
         self.api_token = kwargs.get('api_token', None)
         self.timeout = kwargs.get('timeout', None)
+        self.verify = kwargs.get('verify', None)
 
         self.http = requests.Session()
 
@@ -37,6 +38,9 @@ class CachetClient(object):
         if self.timeout is not None:
             kwargs.setdefault('timeout', self.timeout)
 
+        if self.verify is not None:
+            kwargs.setdefault('verify', self.verify)
+
         kwargs.setdefault('headers', kwargs.get('headers', {}))
         kwargs['headers']['User-Agent'] = self.user_agent
         kwargs['headers']['Accept'] = 'application/json'
